==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/bauble/ExtraLifeBauble.java <==
package com.github.tartaricacid.touhoulittlemaid.item.bauble;

import com.github.tartaricacid.touhoulittlemaid.advancements.maid.TriggerType;
import com.github.tartaricacid.touhoulittlemaid.api.bauble.IMaidBauble;
import com.github.tartaricacid.touhoulittlemaid.api.event.MaidDeathEvent;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitTrigger;
import com.github.tartaricacid.touhoulittlemaid.network.NetworkHandler;
import com.github.tartaricacid.touhoulittlemaid.network.message.SpawnParticlePackage;
import com.github.tartaricacid.touhoulittlemaid.util.ItemsUtil;
import net.minecraft.class_1282;
import net.minecraft.class_1799;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_8103;

public class ExtraLifeBauble implements IMaidBauble {
    public ExtraLifeBauble() {
        MaidDeathEvent.CALLBACK.register(this::onLivingDamage);
    }

    public void onLivingDamage(MaidDeathEvent event) {
        EntityMaid maid = event.getMaid();
        class_1282 source = event.getSource();
        if (!source.method_48789(class_8103.field_42242)) {
            int slot = ItemsUtil.getBaubleSlotInMaid(maid, this);
            if (slot >= 0) {
                event.setCanceled(true);
                class_1799 stack = maid.getMaidBauble().getStackInSlot(slot);
                maid.hurtAndBreak(stack, 1);
                maid.getMaidBauble().setStackInSlot(slot, stack);
                maid.method_6033(maid.method_6063());
                NetworkHandler.sendToNearby(maid, new SpawnParticlePackage(maid.method_5628(), SpawnParticlePackage.Type.HEART));
                maid.method_5783(class_3417.field_15081, 1.0f, 1.0f);
                if (maid.method_35057() instanceof class_3222 serverPlayer) {
                    InitTrigger.MAID_EVENT.trigger(serverPlayer, TriggerType.USE_UNDEAD_BAUBLE);
                }
            }
        }
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.6-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/bauble/ExtraLifeBauble.java <==
package com.github.tartaricacid.touhoulittlemaid.item.bauble;

import com.github.tartaricacid.touhoulittlemaid.advancements.maid.TriggerType;
import com.github.tartaricacid.touhoulittlemaid.api.bauble.IMaidBauble;
import com.github.tartaricacid.touhoulittlemaid.api.event.MaidDeathEvent;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitTrigger;
import com.github.tartaricacid.touhoulittlemaid.network.NetworkHandler;
import com.github.tartaricacid.touhoulittlemaid.network.message.SpawnParticlePackage;
import com.github.tartaricacid.touhoulittlemaid.util.ItemsUtil;
import net.minecraft.class_1282;
import net.minecraft.class_1799;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_8103;

import static cn.sh1rocu.touhoulittlemaid.TouhouLittleMaidFabric.HIGH;

public class ExtraLifeBauble implements IMaidBauble {
    public ExtraLifeBauble() {
        MaidDeathEvent.CALLBACK.register(HIGH, this::onLivingDamage);
    }

    public void onLivingDamage(MaidDeathEvent event) {
        EntityMaid maid = event.getMaid();
        class_1282 source = event.getSource();
        if (!source.method_48789(class_8103.field_42242)) {
            int slot = ItemsUtil.getBaubleSlotInMaid(maid, this);
            if (slot >= 0) {
                event.setCanceled(true);
                class_1799 stack = maid.getMaidBauble().getStackInSlot(slot);
                maid.hurtAndBreak(stack, 1);
                maid.getMaidBauble().setStackInSlot(slot, stack);
                maid.method_6033(maid.method_6063());
                NetworkHandler.sendToNearby(maid, new SpawnParticlePackage(maid.method_5628(), SpawnParticlePackage.Type.HEART));
                maid.method_5783(class_3417.field_15081, 1.0f, 1.0f);
                if (maid.method_35057() instanceof class_3222 serverPlayer) {
                    InitTrigger.MAID_EVENT.trigger(serverPlayer, TriggerType.USE_UNDEAD_BAUBLE);
                }
            }
        }
    }
}
